# sphinx-gha
[![Documentation Status](https://readthedocs.org/projects/sphinx-gha/badge/?version=latest)](https://sphinx-gha.readthedocs.io/en/latest/?badge=latest)
[![build](https://github.com/drewcassidy/sphinx-gha/actions/workflows/build.yml/badge.svg)](https://github.com/drewcassidy/sphinx-gha/actions/workflows/build.yml)
[![PyPI version](https://badge.fury.io/py/sphinx-gha.svg)](https://pypi.org/project/sphinx-gha/)


Sphinx Extension for Documenting GitHub Actions
